@@ -1,4 +1,4 @@
-GOOF----LE-4-2.0      ]  4      hC      ] g  guile	 	g  define-module*	 	 	g  language	g  elisp	g  runtime		 	
+GOOF----LE-4-2.0      ]  4      h`      ] g  guile	 	g  define-module*	 	 	g  language	g  elisp	g  runtime		 	
 g  filenameS	f  language/elisp/runtime.scm	g  exportsS	
 g  	nil-value	g  t-value	g  value-slot-module	g  function-slot-module	g  
 elisp-bool	g  
@@ -11,31 +11,12 @@ defspecial	g  prim	
 value-slot	  	!g  
 function-slot	"! 	#g  error	$g  resolve-interface	%g  resolve-module	&g  module-defined?	'g  make-unbound-fluid	(g  module-define!	)g  module-export!	*g  
 module-ref	+g  module-set!	,g  make-syntax-transformer	-, 	., 	/g  macro	0g  $sc-dispatch	10 	20 	3g  any	4333 	5g  
-syntax-object	6g  begin	7g  top	87 	9g  ribcage	:g  dummy	;g  name	<g  value	=:;< 	>g  
-m-1b909440-25	?>7 	@?88 	Af  
-l-1b909440-2a	Bf  
-l-1b909440-2b	Cf  
-l-1b909440-2c	DABC 	E9=@D 	F9 	Gg  x	HG 	I? 	Jf  
-l-1b909440-27	KJ 	L9HIK 	M8EFL 	Ng  hygiene	ON 	P56MO 	Qg  
+syntax-object	6g  begin	7g  top	87 	9g  ribcage	:g  dummy	;g  name	<g  value	=:;< 	>g  m-lIAHgxL@G6E2TrxNxT6mfE-258	?>7 	@?88 	Af  l-lIAHgxL@G6E2TrxNxT6mfE-263	Bf  l-lIAHgxL@G6E2TrxNxT6mfE-264	Cf  l-lIAHgxL@G6E2TrxNxT6mfE-265	DABC 	E9=@D 	F9 	Gg  x	HG 	I? 	Jf  l-lIAHgxL@G6E2TrxNxT6mfE-260	KJ 	L9HIK 	M8EFL 	Ng  hygiene	ON 	P56MO 	Qg  
 define-public	R5QMO 	Sg  syntax-violation	TS 	US 	Vf  -source expression failed to match any pattern	Wg  
 datum->syntax	Xg  map	Yg  identifier?	Zg  
 syntax->datum	[g  identity	\g  string->symbol	]g  
-string-append	^g  symbol->string	_g  make-id	`g  _	a`33 	bg  macro-	cg  scheme-name	dc 	e8 	ff  
-l-1b909440-44	gf 	h9deg 	i;< 	j88 	kf  
-l-1b909440-3e	lf  
-l-1b909440-3f	mkl 	n9ijm 	of  
-l-1b909440-3b	po 	q9Hep 	r8FhnFq 	s56rO 	t5QrO 	ug  
-make-fluid	v5urO 	wg  cons	x5wrO 	yg  quote	z5yrO 	{5/rO 	|z{ 	}g  each-any	~3}	3~ ` g  compile- f  
-l-1b909440-52   9de  g  args g  body ;  888  f  
-l-1b909440-4a f  
-l-1b909440-4b f  
-l-1b909440-4c   9  f  
-l-1b909440-47   9He  8FF  56O  g  define 5O  5uO  5wO  5yO  g  special-operator 5O    g  lambda 5O  g  @ g  sym :  g  
-m-1b909440-55 7  88  f  
-l-1b909440-5a f  
-l-1b909440-5b f  
-l-1b909440-5c   9    f  
-l-1b909440-57   9H  8F  5O  5O   C 5h     ]4	
+string-append	^g  symbol->string	_g  make-id	`g  _	a`33 	bg  macro-	cg  scheme-name	dc 	e8 	ff  l-lIAHgxL@G6E2TrxNxT6mfE-289	gf 	h9deg 	i;< 	j88 	kf  l-lIAHgxL@G6E2TrxNxT6mfE-283	lf  l-lIAHgxL@G6E2TrxNxT6mfE-284	mkl 	n9ijm 	of  l-lIAHgxL@G6E2TrxNxT6mfE-280	po 	q9Hep 	r8FhnFq 	s56rO 	t5QrO 	ug  
+make-fluid	v5urO 	wg  cons	x5wrO 	yg  quote	z5yrO 	{5/rO 	|z{ 	}g  each-any	~3}	3~ ` g  compile- f  l-lIAHgxL@G6E2TrxNxT6mfE-303   9de  g  args g  body ;  888  f  l-lIAHgxL@G6E2TrxNxT6mfE-295 f  l-lIAHgxL@G6E2TrxNxT6mfE-296 f  l-lIAHgxL@G6E2TrxNxT6mfE-297   9  f  l-lIAHgxL@G6E2TrxNxT6mfE-292   9He  8FF  56O  g  define 5O  5uO  5wO  5yO  g  special-operator 5O    g  lambda 5O  g  @ g  sym :  g  m-lIAHgxL@G6E2TrxNxT6mfE-306 7  88  f  l-lIAHgxL@G6E2TrxNxT6mfE-311 f  l-lIAHgxL@G6E2TrxNxT6mfE-312 f  l-lIAHgxL@G6E2TrxNxT6mfE-313   9    f  l-lIAHgxL@G6E2TrxNxT6mfE-308   9H  8F  5O  5O   C 5   h     ]4	
 5 4 >  "  G   
 RR R"R#        h      - 1 3  @              g  msg
 			 g  args			  g  filenamef  language/elisp/runtime.scm
